import React, { useImperativeHandle, useRef, useState } from 'react';
import { View, UIManager, findNodeHandle, Text, Platform, StyleSheet, TouchableOpacity, Image } from 'react-native';
import { VisionSdkView } from './VisionSdkViewManager';
var ScanMode; // enum AutoMode  ["auto", "manual"]
(function (ScanMode) {
  ScanMode["OCR"] = "ocr";
  ScanMode["BARCODE"] = "barcode";
  ScanMode["QRCODE"] = "qrcode";
})(ScanMode || (ScanMode = {}));
const Camera = _ref => {
  let {
    children,
    refProp,
    BarCodeScanHandler = _e => {},
    OCRScanHandler = _e => {},
    onError = _e => {}
  } = _ref;
  const defaultScanMode = ScanMode.OCR;
  const [mode, setMode] = useState(defaultScanMode);
  const [captureMode, setCaptureMode] = useState('auto');
  // const [apiKey, setAPIKey] = useState < String > ('key_stag_7da7b5e917tq2eCckhc5QnTr1SfpvFGjwbTfpu1SQYy242xPjBz2mk3hbtzN6eB85MftxVw1zj5K5XBF')

  const VisionSDKViewRef = useRef(null);
  useImperativeHandle(refProp, () => ({
    cameraCaptureHandler: () => {
      onPressCaptures();
    },
    changeModeHandler: input => {
      onChangeMode(input);
    }
  }));
  const onPressCaptures = () => {
    UIManager.dispatchViewManagerCommand(findNodeHandle(VisionSDKViewRef.current), UIManager.hasViewManagerConfig('VisionSDKView') && UIManager.getViewManagerConfig('VisionSDKView').Commands.captureImage || 0, []);
  };
  const onChangeMode = input => {
    setMode(input);
  };
  return Platform.OS === 'ios' ? /*#__PURE__*/React.createElement(VisionSdkView, {
    style: styles.flex,
    onBarcodeScanSuccess: BarCodeScanHandler,
    onOCRDataReceived: OCRScanHandler
    // onDetected={onDetected}
    // OnDetectedHandler={OnDetectedHandler}
    // onOCRDataReceived={({ nativeEvent }) =>
    //   console.log('onOCRDataReceived', nativeEvent)
    // }
    // onBarcodeScanSuccess={({ nativeEvent }) =>
    //   console.log('onBarcodeScanSuccess', nativeEvent)
    // }
    ,
    mode: mode,
    apiKey: 'key_stag_7da7b5e917tq2eCckhc5QnTr1SfpvFGjwbTfpu1SQYy242xPjBz2mk3hbtzN6eB85MftxVw1zj5K5XBF',
    captureMode: 'auto',
    onError: onError
    // onDetected={onDetected}
    ,
    ref: VisionSDKViewRef
  }, /*#__PURE__*/React.createElement(View, {
    style: [styles.childrenContainer]
  }, /*#__PURE__*/React.createElement(View, {
    style: [styles.row, {
      paddingHorizontal: 20,
      alignItems: 'flex-start'
    }]
  }, /*#__PURE__*/React.createElement(View, null, /*#__PURE__*/React.createElement(View, {
    style: styles.circle
  })), /*#__PURE__*/React.createElement(View, null, /*#__PURE__*/React.createElement(View, {
    style: styles.circle
  }), /*#__PURE__*/React.createElement(View, {
    style: styles.circle
  }), /*#__PURE__*/React.createElement(View, {
    style: styles.circle
  }))), /*#__PURE__*/React.createElement(View, null, /*#__PURE__*/React.createElement(View, {
    style: [styles.row, {
      marginBottom: 10,
      paddingHorizontal: 20
    }]
  }, /*#__PURE__*/React.createElement(View, null, /*#__PURE__*/React.createElement(View, {
    style: styles.circle
  })), mode === ScanMode.OCR && /*#__PURE__*/React.createElement(View, {
    style: styles.zoomBlock
  }, /*#__PURE__*/React.createElement(View, {
    style: [styles.circle]
  }), /*#__PURE__*/React.createElement(View, {
    style: styles.circle
  }), /*#__PURE__*/React.createElement(View, {
    style: styles.circle
  })), mode !== ScanMode.OCR && /*#__PURE__*/React.createElement(View, {
    style: styles.autoManualBlock
  }, /*#__PURE__*/React.createElement(ActionButton, {
    text: 'Manual',
    textColor: '#000',
    style: captureMode === 'manual' && styles.unautoManualButton
    // isSeleted={mode === ScanMode.OCR}
    ,
    onPress: () => setCaptureMode('manual')
  }), /*#__PURE__*/React.createElement(ActionButton, {
    text: 'Auto',
    textColor: '#000',
    style: captureMode === 'auto' && styles.autoManualButton
    // isSeleted={mode === ScanMode.OCR}
    ,
    onPress: () => setCaptureMode('auto')
  })), /*#__PURE__*/React.createElement(View, null, /*#__PURE__*/React.createElement(View, {
    style: styles.circle
  }))), /*#__PURE__*/React.createElement(View, {
    style: {
      backgroundColor: '#000',
      width: '100%',
      paddingVertical: 20
    }
  }, /*#__PURE__*/React.createElement(View, {
    style: [styles.row, {
      justifyContent: 'space-around'
    }]
  }, /*#__PURE__*/React.createElement(ActionButton, {
    text: 'BarCode',
    isSeleted: mode === ScanMode.BARCODE,
    onPress: () => setMode(ScanMode.BARCODE)
  }), /*#__PURE__*/React.createElement(ActionButton, {
    text: 'QR Code',
    isSeleted: mode === ScanMode.QRCODE,
    onPress: () => setMode(ScanMode.QRCODE)
  }), /*#__PURE__*/React.createElement(ActionButton, {
    text: 'OCR',
    isSeleted: mode === ScanMode.OCR,
    onPress: () => setMode(ScanMode.OCR)
  })), captureMode === 'manual' ? /*#__PURE__*/React.createElement(View, {
    style: {
      alignItems: 'center',
      justifyContent: 'center',
      paddingVertical: 20
    }
  }, /*#__PURE__*/React.createElement(ActionButton, {
    text: 'OCR',
    textColor: '#000',
    style: {
      backgroundColor: '#fff',
      width: 70,
      height: 70,
      borderRadius: 35,
      alignItems: 'center',
      justifyContent: 'center',
      paddingVertical: 20
    },
    onPress: () => onPressCaptures()
  })) : /*#__PURE__*/React.createElement(View, null)))), children) : /*#__PURE__*/React.createElement(View, {
    style: styles.flex
  }, /*#__PURE__*/React.createElement(Text, null, "NOT IMPLEMENTED FOR ANDROID YET."));
};
export default Camera;
const ActionButton = _ref2 => {
  let {
    text,
    onPress,
    isSeleted,
    icon,
    style,
    textColor
  } = _ref2;
  return /*#__PURE__*/React.createElement(TouchableOpacity, {
    style: [style && style],
    onPress: onPress
  }, /*#__PURE__*/React.createElement(Text, {
    style: [isSeleted ? styles.buttonText : styles.unbuttonText, textColor && {
      color: textColor
    }]
  }, text), icon ?? /*#__PURE__*/React.createElement(Image, {
    source: icon
  }));
};
const styles = StyleSheet.create({
  flex: {
    flex: 1
  },
  row: {
    flexDirection: 'row',
    alignItems: 'center',
    justifyContent: 'space-between'
  },
  buttonText: {
    fontSize: 15,
    color: 'yellow'
  },
  unbuttonText: {
    fontSize: 15,
    color: 'white'
  },
  zoomBlock: {
    paddingHorizontal: 5,
    borderRadius: 30,
    height: 40,
    flexDirection: 'row',
    backgroundColor: '#00000050',
    justifyContent: 'space-between'
  },
  autoManualBlock: {
    borderRadius: 4,
    // paddingHorizontal: 2,
    height: 40,
    alignItems: 'center',
    flexDirection: 'row',
    backgroundColor: 'grey',
    justifyContent: 'space-between'
  },
  autoManualButton: {
    backgroundColor: '#fff',
    width: 80,
    borderRadius: 4,
    height: 30,
    marginHorizontal: 4,
    paddingHorizontal: 10,
    alignItems: 'center',
    justifyContent: 'center'
  },
  unautoManualButton: {
    backgroundColor: 'grey',
    width: 80,
    borderRadius: 4,
    height: 30,
    marginHorizontal: 4,
    paddingHorizontal: 10,
    alignItems: 'center',
    justifyContent: 'center'
  },
  circle: {
    width: 30,
    height: 30,
    borderRadius: 40,
    marginVertical: 5,
    marginHorizontal: 5,
    backgroundColor: '#00000050'
  },
  childrenContainer: {
    paddingTop: 20,
    justifyContent: 'space-between',
    position: 'absolute',
    top: 0,
    left: 0,
    height: '100%',
    width: '100%'
  }
});
//# sourceMappingURL=index.js.map